Skip to main content

Aind.Behavior.VrForaging.Curricula

CI License ruff uv

A repository of curricula for VR foraging task.

How to run a specific curriculum?

Curricula are modules of the main package: aind_behavior_vr_foraging_curricula.<curriculum_name>.

All curricula are available via the curriculum cli entry point. Available list of commands is printed with the -h flag:

uv run curriculum -h

List available curricula

Available curricula can be listed from the cli using:

uv run curriculum list

Running a curriculum

Curricula can be run using the run subcommand of the curriculum cli entry point.

uv run curriculum run -h

The following arguments are available for the run subcommand:

  • --data-directory: Path to the session data directory that will be used to calculate metrics (required)
  • --input-trainer-state: Path to a deserialized json file with the current trainer state (required)
  • --mute-suggestion: Disables the suggestion output (optional)
  • --output-suggestion: A path to save the serialized suggestion (optional)
  • --curriculum: The name of the curriculum to run (optional)

For a quick "demo" to ensure everything is working, you can run:

uv run curriculum run --data-directory "demo" --input-trainer-state "foo.json" --curriculum "template"

For real-world applications, you may want to omit the "--curriculum" flag and let the system automatically detect the curriculum from the trainer state.

Style guide

To keep things clear, I suggest the following naming convention:

  • Policies should start with p_ (e.g., p_identity_policy)
  • Policy transitions should start with pt_
  • Stages should start with s_ (e.g., s_stage1)
  • Stage transitions should start with st_ and should be named after the stages they transition between (e.g., st_s_stage1_s_stage2)

Define the following modules:

  • metrics: Defines (or imports) metrics classes and how to calculate them from data
  • stages: Defines the different stages of the VR foraging task. This includes task settings and, optionally, policies
  • curriculum: Defines the transitions between the stages and generate entry point to the application

Contributors

Contributions to this repository are welcome! However, please ensure that your code adheres to the recommended DevOps practices below:

Linting

We use ruff as our primary linting tool.

Testing

Attempt to add tests when new features are added. To run the currently available tests, run uv run pytest from the root of the repository.

Lock files

We use uv to manage our lock files and therefore encourage everyone to use uv as a package manager as well.

Metadata

Release files for aind-behavior-vr-foraging-curricula 1.2.6

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for aind-behavior-vr-foraging-curricula 1.2.6
File Size Uploaded
aind_behavior_vr_foraging_curricula-1.2.6.tar.gz 39.3 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for aind-behavior-vr-foraging-curricula 1.2.6
File Interpreter ABI Platform
aind_behavior_vr_foraging_curricula-1.2.6-py3-none-any.whl Python 3 none any Details

Total release size: 103.6 kB

Release files / aind_behavior_vr_foraging_curricula-1.2.6.tar.gz

Download URL aind_behavior_vr_foraging_curricula-1.2.6.tar.gz
Size 39.3 kB
Tags Source
SHA-256 checksum
How to use checksums
1d9f01d9d88a96cea2cf7b4743fb8ca9eeda3c38ebcf8ebcc066fb5a86790a9c
BLAKE2b-256 checksum
How to use checksums
a64d6b73c97d2ab5ecd891745db2159199b72b32b49e610962a57a1d646b9a9d
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via uv/0.12.13 {"installer":{"name":"uv","version":"0.12.13","subcommand":["publish"]},"python":null,"implementation":{"name":null,"version":null},"distro":{"name":"Ubuntu","version":"24.04","id":"noble","libc":null},"system":{"name":null,"release":null},"cpu":null,"openssl_version":null,"setuptools_version":null,"rustc_version":null,"ci":true}

Release files / aind_behavior_vr_foraging_curricula-1.2.6-py3-none-any.whl

Download URL aind_behavior_vr_foraging_curricula-1.2.6-py3-none-any.whl
Size 64.2 kB
Tags Python 3
SHA-256 checksum
How to use checksums
13d44b5c37b4b349c57004e602520d45f11221b124410b9a34d0e58822044606
BLAKE2b-256 checksum
How to use checksums
b2c1a8b5d85e887328cdcff9dc2ff0706aba983241de5317cfedaa9ddc499047
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via uv/0.12.13 {"installer":{"name":"uv","version":"0.12.13","subcommand":["publish"]},"python":null,"implementation":{"name":null,"version":null},"distro":{"name":"Ubuntu","version":"24.04","id":"noble","libc":null},"system":{"name":null,"release":null},"cpu":null,"openssl_version":null,"setuptools_version":null,"rustc_version":null,"ci":true}
Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page